# ✨ Welcome to panel-material-ui

<table>
<tbody>
<tr>
<td>Downloads</td>
<td><a href="https://pypistats.org/packages/panel-material-ui"><img src="https://img.shields.io/pypi/dm/panel-material-ui?label=pypi" alt="PyPi Downloads" /></a></td>
</tr>
<tr>
<td>Build Status</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/actions/workflows/test.yaml?query=branch%3Amain"><img src="https://github.com/panel-extensions/panel-material-ui/workflows/tests/badge.svg?query=branch%3Amain" alt="Linux/MacOS Build Status"></a></td>
</tr>
<tr>
<td>Coverage</td>
<td><a href="https://codecov.io/gh/panel-extensions/panel-material-ui"><img src="https://codecov.io/gh/panel-extensions/panel-material-ui/branch/main/graph/badge.svg" alt="codecov"></a></td>
</tr>
<tr>
<td>Latest dev release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tags"><img src="https://img.shields.io/github/v/tag/panel-extensions/panel-material-ui.svg?label=tag&amp;colorB=11ccbb" alt="Github tag"></a> <a href="https://holoviz-dev.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/holoviz-dev.github.io/panel-material-ui.svg?label=dev%20website" alt="dev-site"></a></td>
</tr>
<tr>
<td>Latest release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/releases"><img src="https://img.shields.io/github/release/panel-extensions/panel-material-uiel.svg?label=tag&amp;colorB=11ccbb" alt="Github release"></a> <a href="https://pypi.python.org/pypi/panel-material-ui"><img src="https://img.shields.io/pypi/v/panel-material-ui.svg?colorB=cc77dd" alt="PyPI version"></a> <a href="https://anaconda.org/pyviz/panel-material-ui"><img src="https://img.shields.io/conda/v/pyviz/panel-material-ui.svg?label=conda%7Cpyviz&colorB=4488ff&amp;style=flat" alt="panel version"></a> <a href="https://anaconda.org/conda-forge/panel-material-ui"><img src="https://img.shields.io/conda/v/conda-forge/panel-material-ui.svg?label=conda%7Cconda-forge&amp;colorB=4488ff" alt="conda-forge version"></a> <a href="https://anaconda.org/anaconda/panel-material-ui"><img src="https://img.shields.io/conda/v/anaconda/panel-material-ui.svg?label=conda%7Cdefaults&amp;style=flat&amp;colorB=4488ff" alt="defaults version"></a></td>
</tr>
<tr>
<td>Docs</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tree/gh-pages"><img src="https://img.shields.io/github/last-commit/panel-extensions/panel-material-ui/gh-pages.svg" alt="gh-pages"></a> <a href="https://panel-extensions.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/panel-extensions.github.io/panel-material-ui.svg" alt="site"></a>
</td>
</tr>
<tr>
<td>Support</td>
<td><a href="https://discourse.holoviz.org/"><img src="https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org" alt="Discourse"></a> <a href="https://discord.gg/rb6gPXbdAr"><img alt="Discord" src="https://img.shields.io/discord/1075331058024861767"></a>
</td>
</tr>
</tbody>
</table>


An extension to bring MaterialUI components to Panel.

## Installation

Install `panel-material-ui` via `pip`:

```bash
pip install panel-material-ui
```

## ❤️ Contributions

Contributions and co-maintainers are very welcome! Please submit issues or pull requests to the [GitHub repository](https://github.com/panel-extensions/panel-material-ui). Check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md) for more information.
